Segregation Tutorial
======================

.. toctree::
    :maxdepth: 1
    :caption: Contents:

    notebooks/01_singlegroup_indices.ipynb
    notebooks/02_multigroup_indices.ipynb
    notebooks/03_local_indices.ipynb
    notebooks/04_multiscalar_example.ipynb
    notebooks/05_inference_example.ipynb
    notebooks/06_decomposition_example.ipynb
